@@ -32,7 +32,7 @@ import decimal
 import datetime
 import time
 
-VERSION = (0, 2, 6)
+VERSION = (0, 2, 7)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -623,10 +623,16 @@ class Connection(object):
             raise OperationalError(u"08003:Lost connection")
         r = b''
         while len(r) < ln:
-            r += self.sock.recv(ln-len(r))
+            b = self.sock.recv(ln-len(r))
+            if not b:
+                raise OperationalError(u"08003:Can't recv packets")
+            r += b
         return r
 
     def _write(self, b):
+        if sys.platform == 'cli':
+            # A workaround for IronPython 2.7.5b2 problem
+            b = str(b)
         if not self.sock:
             raise OperationalError(u"08003:Lost connection")
         n = 0
